/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

/*
 *  ATTENTION!
 *  THIS IS A GENERATED FILE FROM https://github.com/salesforce-experience-platform-emu/lds-lightning-platform
 *  If you would like to contribute to LDS, please follow the steps outlined in the git repo.
 *  Any changes made to this file in p4 will be automatically overwritten.
 *  *******************************************************************************************
 */
/* proxy-compat-disable */
import { createInstrumentedAdapter, createLDSAdapter, createWireAdapterConstructor, createImperativeAdapter } from 'force/ldsBindings';
import { withDefaultLuvio } from 'force/ldsEngine';
import { serializeStructuredKey, ingestShape, deepFreeze, buildNetworkSnapshotCachePolicy as buildNetworkSnapshotCachePolicy$1, StoreKeyMap, createResourceParams as createResourceParams$1 } from 'force/luvioEngine';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys$1, create: ObjectCreate$1 } = Object;
const { isArray: ArrayIsArray$1 } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys$1(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray$1(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const snapshotRefreshOptions = {
    overrides: {
        headers: {
            'Cache-Control': 'no-cache',
        },
    }
};
function buildAdapterValidationConfig(displayName, paramsMeta) {
    const required = paramsMeta.filter(p => p.required).map(p => p.name);
    const optional = paramsMeta.filter(p => !p.required).map(p => p.name);
    return {
        displayName,
        parameters: {
            required,
            optional,
        }
    };
}
const keyPrefix = 'cdp-data-transform-experience';

const { keys: ObjectKeys, create: ObjectCreate, assign: ObjectAssign } = Object;
const { isArray: ArrayIsArray } = Array;
const { stringify: JSONStringify } = JSON;
function createLink(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}

function validate$1(obj, path = 'DataTransformExperienceAppSettingsRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_formattersLocale = obj.formattersLocale;
        const path_formattersLocale = path + '.formattersLocale';
        if (typeof obj_formattersLocale !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_formattersLocale + '" (at "' + path_formattersLocale + '")');
        }
        const obj_isFileRecoveryEnabled = obj.isFileRecoveryEnabled;
        const path_isFileRecoveryEnabled = path + '.isFileRecoveryEnabled';
        if (typeof obj_isFileRecoveryEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isFileRecoveryEnabled + '" (at "' + path_isFileRecoveryEnabled + '")');
        }
        const obj_isRecommendationsEnabled = obj.isRecommendationsEnabled;
        const path_isRecommendationsEnabled = path + '.isRecommendationsEnabled';
        if (typeof obj_isRecommendationsEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isRecommendationsEnabled + '" (at "' + path_isRecommendationsEnabled + '")');
        }
        const obj_isTelemetryEnabled = obj.isTelemetryEnabled;
        const path_isTelemetryEnabled = path + '.isTelemetryEnabled';
        if (typeof obj_isTelemetryEnabled !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isTelemetryEnabled + '" (at "' + path_isTelemetryEnabled + '")');
        }
        const obj_maxConcurrentSessionPerUser = obj.maxConcurrentSessionPerUser;
        const path_maxConcurrentSessionPerUser = path + '.maxConcurrentSessionPerUser';
        if (typeof obj_maxConcurrentSessionPerUser !== 'number') {
            return new TypeError('Expected "number" but received "' + typeof obj_maxConcurrentSessionPerUser + '" (at "' + path_maxConcurrentSessionPerUser + '")');
        }
        const obj_samplingMaxRowLimit = obj.samplingMaxRowLimit;
        const path_samplingMaxRowLimit = path + '.samplingMaxRowLimit';
        if (typeof obj_samplingMaxRowLimit !== 'number') {
            return new TypeError('Expected "number" but received "' + typeof obj_samplingMaxRowLimit + '" (at "' + path_samplingMaxRowLimit + '")');
        }
        const obj_textLocale = obj.textLocale;
        const path_textLocale = path + '.textLocale';
        if (typeof obj_textLocale !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_textLocale + '" (at "' + path_textLocale + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const VERSION = "bf126a11521eabfe4b45a2bcfa7f91a4";
function validate(obj, path = 'DataTransformExperienceConfigurationRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_appSettings = obj.appSettings;
        const path_appSettings = path + '.appSettings';
        const referencepath_appSettingsValidationError = validate$1(obj_appSettings, path_appSettings);
        if (referencepath_appSettingsValidationError !== null) {
            let message = 'Object doesn\'t match DataTransformExperienceAppSettingsRepresentation (at "' + path_appSettings + '")\n';
            message += referencepath_appSettingsValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
            return new TypeError(message);
        }
        const obj_featureFlags = obj.featureFlags;
        const path_featureFlags = path + '.featureFlags';
        if (typeof obj_featureFlags !== 'object' || ArrayIsArray(obj_featureFlags) || obj_featureFlags === null) {
            return new TypeError('Expected "object" but received "' + typeof obj_featureFlags + '" (at "' + path_featureFlags + '")');
        }
        const obj_featureFlags_keys = ObjectKeys(obj_featureFlags);
        for (let i = 0; i < obj_featureFlags_keys.length; i++) {
            const key = obj_featureFlags_keys[i];
            const obj_featureFlags_prop = obj_featureFlags[key];
            const path_featureFlags_prop = path_featureFlags + '["' + key + '"]';
            if (typeof obj_featureFlags_prop !== 'boolean') {
                return new TypeError('Expected "boolean" but received "' + typeof obj_featureFlags_prop + '" (at "' + path_featureFlags_prop + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType = 'DataTransformExperienceConfigurationRepresentation';
function normalize(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1 = function DataTransformExperienceConfigurationRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION,
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest = function DataTransformExperienceConfigurationRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 360000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize, "cdp-data-transform-experience", VERSION, RepresentationType, equals);
    return createLink(key);
};
function getTypeCacheKeys(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType,
        mergeable: false
    });
}

function select(luvio, params) {
    return select$1();
}
function keyBuilder$1(luvio, params) {
    return keyPrefix + '::DataTransformExperienceConfigurationRepresentation:(' + ')';
}
function getResponseCacheKeys(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys(storeKeyMap, luvio, response, () => keyBuilder$1());
}
function ingestSuccess(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1();
    luvio.storeIngest(key, ingest, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1();
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v63.0',
        basePath: '/ssot/data-transforms-experience/configurations',
        method: 'get',
        body: null,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName = 'getDataTransformsExperienceConfiguration';
const getDataTransformsExperienceConfiguration_ConfigPropertyMetadata = [];
const getDataTransformsExperienceConfiguration_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName, getDataTransformsExperienceConfiguration_ConfigPropertyMetadata);
const createResourceParams = /*#__PURE__*/ createResourceParams$1(getDataTransformsExperienceConfiguration_ConfigPropertyMetadata);
function keyBuilder(luvio, config) {
    createResourceParams(config);
    return keyBuilder$1();
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig();
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment(luvio, config) {
    createResourceParams(config);
    return select();
}
function onFetchResponseSuccess(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError(luvio, config, resourceParams, response) {
    const snapshot = ingestError(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot(luvio, config, options) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest();
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$1(context, coercedAdapterRequestContext, buildNetworkSnapshot, undefined, false);
}
function buildCachedSnapshotCachePolicy(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder(luvio, config),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const getDataTransformsExperienceConfigurationAdapterFactory = (luvio) => function cdpDataTransformExperience__getDataTransformsExperienceConfiguration(untrustedConfig, requestContext) {
    const config = validateAdapterConfig(untrustedConfig, getDataTransformsExperienceConfiguration_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy, buildNetworkSnapshotCachePolicy);
};

let getDataTransformsExperienceConfiguration;
// Imperative GET Adapters
let getDataTransformsExperienceConfiguration_imperative;
// Adapter Metadata
const getDataTransformsExperienceConfigurationMetadata = {
    apiFamily: 'cdpdata-transform-experience',
    name: 'getDataTransformsExperienceConfiguration',
};
// Notify Update Available
function bindExportsTo(luvio) {
    // LDS Adapters
    const getDataTransformsExperienceConfiguration_ldsAdapter = createInstrumentedAdapter(createLDSAdapter(luvio, 'getDataTransformsExperienceConfiguration', getDataTransformsExperienceConfigurationAdapterFactory), getDataTransformsExperienceConfigurationMetadata);
    return {
        getDataTransformsExperienceConfiguration: createWireAdapterConstructor(luvio, getDataTransformsExperienceConfiguration_ldsAdapter, getDataTransformsExperienceConfigurationMetadata),
        // Imperative GET Adapters
        getDataTransformsExperienceConfiguration_imperative: createImperativeAdapter(luvio, getDataTransformsExperienceConfiguration_ldsAdapter, getDataTransformsExperienceConfigurationMetadata),
        // Notify Update Availables
    };
}
withDefaultLuvio((luvio) => {
    ({
        getDataTransformsExperienceConfiguration,
        getDataTransformsExperienceConfiguration_imperative,
    } = bindExportsTo(luvio));
});

export { getDataTransformsExperienceConfiguration, getDataTransformsExperienceConfiguration_imperative };
// version: 1.314.0-022b0c843b
